
/* 
 * Copyright (c) 1993-2003,2012 LAAS/CNRS
 * All rights reserved.
 *
 * Redistribution and use  in source  and binary  forms,  with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *   1. Redistributions of  source  code must retain the  above copyright
 *      notice, this list of conditions and the following disclaimer.
 *   2. Redistributions in binary form must reproduce the above copyright
 *      notice,  this list of  conditions and the following disclaimer in
 *      the  documentation  and/or  other   materials provided  with  the
 *      distribution.
 *
 * THIS  SOFTWARE IS PROVIDED BY  THE  COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND  ANY  EXPRESS OR IMPLIED  WARRANTIES,  INCLUDING,  BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES  OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR  PURPOSE ARE DISCLAIMED. IN  NO EVENT SHALL THE COPYRIGHT
 * HOLDERS OR      CONTRIBUTORS  BE LIABLE FOR   ANY    DIRECT, INDIRECT,
 * INCIDENTAL,  SPECIAL,  EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 * BUT NOT LIMITED TO, PROCUREMENT OF  SUBSTITUTE GOODS OR SERVICES; LOSS
 * OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN  CONTRACT, STRICT LIABILITY, OR
 * TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
 * USE   OF THIS SOFTWARE, EVEN   IF ADVISED OF   THE POSSIBILITY OF SUCH
 * DAMAGE.
 */

/*------------------  Fichier gnr automatiquement ------------------*/
/*------------------  Ne pas diter manuellement !!! ------------------*/

#ifndef regionMap_MSG_LIB_H
#define regionMap_MSG_LIB_H

#include "portLib.h"
#include "csLib.h"
#include "posterLib.h"
 
#include "regionMapType.h"

#define TIME_WAIT_REPLY           /*2000*/ 0
 



/*----------- Tailles des messages et boites aux lettres  ----------*/

/* Taille du buffer utilise dans la bal pour un mesage de taille size
 * (cf servMbox pour UNIX et h2rgnLib pour VXWORKS )
 */


#define BUF_SIZE(size) \
   (size + 4 - (size & 3) + sizeof(LETTER_HDR) + 8)

/**
 ** Boite aux lettres reception requetes 
 **/
#define  REGIONMAP_MBOX_NAME                  genomInstanceName("regionMap")

#define  REGIONMAP_MAX_RQST_SIZE              2096

#define  REGIONMAP_MBOX_RQST_SIZE       \
 (BUF_SIZE(REGIONMAP_MAX_RQST_SIZE) * SERV_NMAX_RQST_ID)

/** 
 ** Taille max repliques (serveur)
 **/
#define  REGIONMAP_MAX_INTERMED_REPLY_SIZE   (sizeof(int))

#define  REGIONMAP_MAX_REPLY_SIZE             2060

/** 
 ** Taille bal clients pour reception repliques 
 **/
#define  REGIONMAP_CLIENT_MBOX_REPLY_SIZE   \
((BUF_SIZE(REGIONMAP_MAX_REPLY_SIZE) \
   + BUF_SIZE(REGIONMAP_MAX_INTERMED_REPLY_SIZE)) \
 * CLIENT_NMAX_RQST_ID)

/*-------------------------- Liste des requetes  -------------------------*/

#define REGIONMAP_INIT_RQST 0
#define REGIONMAP_CONNECT_RQST 1
#define REGIONMAP_LOADMAP_RQST 2
#define REGIONMAP_LOADPGMMAP_RQST 3
#define REGIONMAP_LOADRESSACMAP_RQST 4
#define REGIONMAP_SETSAVEPARAMS_RQST 5
#define REGIONMAP_GETSAVEPARAMS_RQST 6
#define REGIONMAP_SAVE_RQST 7
#define REGIONMAP_PRINTMAPINFOS_RQST 8
#define REGIONMAP_SETCIRCULARAREA_RQST 9
#define REGIONMAP_SETLOCALCIRCULARAREA_RQST 10
#define REGIONMAP_UPDATEMAP_RQST 11
#define REGIONMAP_UPDATELIGHTPOSTER_RQST 12
#define REGIONMAP_SAVEPOSTER_RQST 13
#define REGIONMAP_INITDISPLAY_RQST 14
#define REGIONMAP_STOPDISPLAY_RQST 15
#define REGIONMAP_UPDATEDISPLAY_RQST 16
#define REGIONMAP_GETDISPLAYPARAMS_RQST 17
#define REGIONMAP_ABORT_RQST 18


/*---------------- PROTOTYPES DES FONCTIONS EXTERNES ------------------*/

#ifdef __cplusplus
extern "C" {
#endif

STATUS regionMapClientInit (CLIENT_ID *pClientId);

STATUS regionMapClientEnd (CLIENT_ID clientId);

int regionMapAbortRqstSend (CLIENT_ID clientId, 
			   int *pRqstId,
			   int *activity,
			   int replyTimeOut);

int regionMapAbortReplyRcv (CLIENT_ID clientId, 
			   int rqstId, 
			   int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			   int *bilan);

int regionMapAbortRqstAndRcv (CLIENT_ID clientId, 
			     int *activity,
			     int *bilan);




extern STATUS regionMapInitRqstSend (CLIENT_ID clientId, int *pRqstId,
					 rmapInitParams *(in_initParams),
					 int replyTimeOut);

extern int regionMapInitReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int regionMapInitRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					rmapInitParams *(in_initParams), 
					
					int *activity, int *bilan);

extern int regionMapInitRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					rmapInitParams *(in_initParams), 
					
					int *activity,
					int *bilan);




extern STATUS regionMapConnectRqstSend (CLIENT_ID clientId, int *pRqstId,
					 rmapConnectionParams *(in_connectionParams),
					 int replyTimeOut);

extern int regionMapConnectReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int regionMapConnectRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					rmapConnectionParams *(in_connectionParams), 
					
					int *activity, int *bilan);

extern int regionMapConnectRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					rmapConnectionParams *(in_connectionParams), 
					
					int *activity,
					int *bilan);




extern STATUS regionMapLoadMapRqstSend (CLIENT_ID clientId, int *pRqstId,
					 rmapLoadParams *(in_loadParams),
					 int replyTimeOut);

extern int regionMapLoadMapReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int regionMapLoadMapRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					rmapLoadParams *(in_loadParams), 
					
					int *activity, int *bilan);

extern int regionMapLoadMapRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					rmapLoadParams *(in_loadParams), 
					
					int *activity,
					int *bilan);




extern STATUS regionMapLoadPgmMapRqstSend (CLIENT_ID clientId, int *pRqstId,
					 rmapLoadPgmParams *(in_loadPgmParams),
					 int replyTimeOut);

extern int regionMapLoadPgmMapReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int regionMapLoadPgmMapRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					rmapLoadPgmParams *(in_loadPgmParams), 
					
					int *activity, int *bilan);

extern int regionMapLoadPgmMapRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					rmapLoadPgmParams *(in_loadPgmParams), 
					
					int *activity,
					int *bilan);




extern STATUS regionMapLoadRessacMapRqstSend (CLIENT_ID clientId, int *pRqstId,
					 rmapLoadParams *(in_loadParams),
					 int replyTimeOut);

extern int regionMapLoadRessacMapReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int regionMapLoadRessacMapRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					rmapLoadParams *(in_loadParams), 
					
					int *activity, int *bilan);

extern int regionMapLoadRessacMapRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					rmapLoadParams *(in_loadParams), 
					
					int *activity,
					int *bilan);




extern STATUS regionMapSetSaveParamsRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 rmapSaveParams *(in_saveParams),
					 int replyTimeOut);

int regionMapSetSaveParamsReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       
			       int *bilan);

int regionMapSetSaveParamsRqstAndRcv (CLIENT_ID clientId, 
				 rmapSaveParams *(in_saveParams), 
				 
				 int *bilan);




extern STATUS regionMapGetSaveParamsRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 
					 int replyTimeOut);

int regionMapGetSaveParamsReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       rmapSaveParams *(out_saveParams),
			       int *bilan);

int regionMapGetSaveParamsRqstAndRcv (CLIENT_ID clientId, 
				  
				 rmapSaveParams *(out_saveParams),
				 int *bilan);




extern STATUS regionMapSaveRqstSend (CLIENT_ID clientId, int *pRqstId,
					 
					 int replyTimeOut);

extern int regionMapSaveReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int regionMapSaveRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					 
					
					int *activity, int *bilan);

extern int regionMapSaveRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					 
					
					int *activity,
					int *bilan);




extern STATUS regionMapPrintMapInfosRqstSend (CLIENT_ID clientId, int *pRqstId,
					 
					 int replyTimeOut);

extern int regionMapPrintMapInfosReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int regionMapPrintMapInfosRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					 
					
					int *activity, int *bilan);

extern int regionMapPrintMapInfosRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					 
					
					int *activity,
					int *bilan);




extern STATUS regionMapSetCircularAreaRqstSend (CLIENT_ID clientId, int *pRqstId,
					 rmapCircleParams *(in_circleParams),
					 int replyTimeOut);

extern int regionMapSetCircularAreaReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int regionMapSetCircularAreaRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					rmapCircleParams *(in_circleParams), 
					
					int *activity, int *bilan);

extern int regionMapSetCircularAreaRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					rmapCircleParams *(in_circleParams), 
					
					int *activity,
					int *bilan);




extern STATUS regionMapSetLocalCircularAreaRqstSend (CLIENT_ID clientId, int *pRqstId,
					 rmapRadiusParams *(in_radiusParams),
					 int replyTimeOut);

extern int regionMapSetLocalCircularAreaReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int regionMapSetLocalCircularAreaRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					rmapRadiusParams *(in_radiusParams), 
					
					int *activity, int *bilan);

extern int regionMapSetLocalCircularAreaRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					rmapRadiusParams *(in_radiusParams), 
					
					int *activity,
					int *bilan);




extern STATUS regionMapUpdateMapRqstSend (CLIENT_ID clientId, int *pRqstId,
					 
					 int replyTimeOut);

extern int regionMapUpdateMapReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int regionMapUpdateMapRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					 
					
					int *activity, int *bilan);

extern int regionMapUpdateMapRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					 
					
					int *activity,
					int *bilan);




extern STATUS regionMapUpdateLightPosterRqstSend (CLIENT_ID clientId, int *pRqstId,
					 
					 int replyTimeOut);

extern int regionMapUpdateLightPosterReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int regionMapUpdateLightPosterRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					 
					
					int *activity, int *bilan);

extern int regionMapUpdateLightPosterRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					 
					
					int *activity,
					int *bilan);




extern STATUS regionMapSavePosterRqstSend (CLIENT_ID clientId, int *pRqstId,
					 
					 int replyTimeOut);

extern int regionMapSavePosterReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int regionMapSavePosterRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					 
					
					int *activity, int *bilan);

extern int regionMapSavePosterRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					 
					
					int *activity,
					int *bilan);




extern STATUS regionMapInitDisplayRqstSend (CLIENT_ID clientId, int *pRqstId,
					 rmapDisplayParams *(in_displayParams),
					 int replyTimeOut);

extern int regionMapInitDisplayReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int regionMapInitDisplayRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					rmapDisplayParams *(in_displayParams), 
					
					int *activity, int *bilan);

extern int regionMapInitDisplayRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					rmapDisplayParams *(in_displayParams), 
					
					int *activity,
					int *bilan);




extern STATUS regionMapStopDisplayRqstSend (CLIENT_ID clientId, int *pRqstId,
					 
					 int replyTimeOut);

extern int regionMapStopDisplayReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int regionMapStopDisplayRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					 
					
					int *activity, int *bilan);

extern int regionMapStopDisplayRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					 
					
					int *activity,
					int *bilan);




extern STATUS regionMapUpdateDisplayRqstSend (CLIENT_ID clientId, int *pRqstId,
					 
					 int replyTimeOut);

extern int regionMapUpdateDisplayReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int regionMapUpdateDisplayRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					 
					
					int *activity, int *bilan);

extern int regionMapUpdateDisplayRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					 
					
					int *activity,
					int *bilan);




extern STATUS regionMapGetDisplayParamsRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 
					 int replyTimeOut);

int regionMapGetDisplayParamsReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       rmapDisplayParams *(out_displayParams),
			       int *bilan);

int regionMapGetDisplayParamsRqstAndRcv (CLIENT_ID clientId, 
				  
				 rmapDisplayParams *(out_displayParams),
				 int *bilan);


#ifdef __cplusplus
}
#endif
#endif /* regionMap_MSG_LIB_H */

